@@ -3,11 +3,12 @@
 
     Original ZynAddSubFX author Nasca Octavian Paul
     Copyright (C) 2002-2009 Nasca Octavian Paul
-    Copyright 2009-2010, Alan Calvert
+    Copyright 2009-2011, Alan Calvert
 
     This file is part of yoshimi, which is free software: you can redistribute
-    it and/or modify it under the terms of version 2 of the GNU General Public
-    License as published by the Free Software Foundation.
+    it and/or modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either version 2 of
+    the License, or (at your option) any later version.
 
     yoshimi is distributed in the hope that it will be useful, but WITHOUT ANY
     WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
@@ -18,10 +19,11 @@
     yoshimi; if not, write to the Free Software Foundation, Inc., 51 Franklin
     Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
-    This file is a derivative of a ZynAddSubFX original, modified October 2010
+    This file is a derivative of a ZynAddSubFX original, modified April 2011
 */
 
 #include <cstring>
+#include <fftw3.h>
 
 #include "Misc/SynthEngine.h"
 #include "DSP/AnalogFilter.h"
@@ -33,7 +35,8 @@ AnalogFilter::AnalogFilter(unsigned char Ftype, float Ffreq, float Fq, unsigned
     q(Fq),
     gain(1.0),
     abovenq(0),
-    oldabovenq(0)
+    oldabovenq(0),
+    tmpismp(NULL)
 {
 
     for (int i = 0; i < 3; ++i)
@@ -46,9 +49,16 @@ AnalogFilter::AnalogFilter(unsigned char Ftype, float Ffreq, float Fq, unsigned
     firsttime = 1;
     d[0] = 0; // this is not used
     outgain = 1.0f;
+    tmpismp = (float*)fftwf_malloc(synth->bufferbytes);
+}
+
+
+AnalogFilter::~AnalogFilter()
+{
+    if (tmpismp)
+        fftwf_free(tmpismp);
 }
 
-AnalogFilter::~AnalogFilter() { }
 
 void AnalogFilter::cleanup()
 {
@@ -61,6 +71,7 @@ void AnalogFilter::cleanup()
     needsinterpolation = 0;
 }
 
+
 void AnalogFilter::computefiltercoefs(void)
 {
     float tmp;
@@ -132,19 +143,21 @@ void AnalogFilter::computefiltercoefs(void)
                 cs = cosf(omega);
                 alpha = sn / (2.0f * tmpq);
                 tmp = 1 + alpha;
-                c[0] = (1.0f - cs) / 2.0f / tmp;
                 c[1] = (1.0f - cs) / tmp;
-                c[2] = (1.0f - cs) / 2.0f / tmp;
+                c[0] = c[2] = c[1] / 2.0f;
                 d[1] = -2.0f * cs / tmp * -1.0f;
                 d[2] = (1.0f - alpha) / tmp * -1.0f;
+
+                //c[0] = (1.0f - cs) / 2.0f / tmp;
+                //c[1] = (1.0f - cs) / tmp;
+                //c[2] = (1.0f - cs) / 2.0f / tmp;
+                //d[1] = -2.0f * cs / tmp * -1.0f;
+                //d[2] = (1.0f - alpha) / tmp * -1.0f;
             }
             else
             {
                 c[0] = 1.0f;
-                c[1] = 0.0f;
-                c[2] = 0.0f;
-                d[1] = 0.0f;
-                d[2] = 0.0f;
+                c[1] = c[2] = d[1] = d[2] = 0.0f;
             }
             order = 2;
             break;
@@ -163,13 +176,7 @@ void AnalogFilter::computefiltercoefs(void)
                 d[2] = (1.0f - alpha) / tmp * -1.0f;
             }
             else
-            {
-                c[0] = 0.0f;
-                c[1] = 0.0f;
-                c[2] = 0.0f;
-                d[1] = 0.0f;
-                d[2] = 0.0f;
-            }
+                c[0] = c[1] = c[2] = d[1] = d[2] = 0.0f;
             order = 2;
             break;
         case 4: // BPF 2 poles
@@ -187,13 +194,7 @@ void AnalogFilter::computefiltercoefs(void)
                 d[2] = (1.0f - alpha) / tmp * -1.0f;
             }
             else
-            {
-                c[0] = 0.0f;
-                c[1] = 0.0f;
-                c[2] = 0.0f;
-                d[1] = 0.0f;
-                d[2] = 0.0f;
-            }
+                c[0] = c[1] = c[2] = d[1] = d[2] = 0.0f;
             order = 2;
             break;
         case 5: // NOTCH 2 poles
@@ -213,10 +214,7 @@ void AnalogFilter::computefiltercoefs(void)
             else
             {
                 c[0] = 1.0f;
-                c[1] = 0.0f;
-                c[2] = 0.0f;
-                d[1] = 0.0f;
-                d[2] = 0.0f;
+                c[1] = c[2] = d[1] = d[2] = 0.0f;
             }
             order = 2;
             break;
@@ -238,10 +236,7 @@ void AnalogFilter::computefiltercoefs(void)
             else
             {
                 c[0] = 1.0f;
-                c[1] = 0.0f;
-                c[2] = 0.0f;
-                d[1] = 0.0f;
-                d[2] = 0.0f;
+                c[1] = c[2] = d[1] = d[2] = 0.0f;
             }
             order = 2;
             break;
@@ -265,10 +260,7 @@ void AnalogFilter::computefiltercoefs(void)
             else
             {
                 c[0] = tmpgain;
-                c[1] = 0.0f;
-                c[2] = 0.0f;
-                d[1] = 0.0f;
-                d[2] = 0.0f;
+                c[1] = c[2] = d[1] = d[2] = 0.0f;
             }
             order = 2;
             break;
@@ -283,7 +275,7 @@ void AnalogFilter::computefiltercoefs(void)
                 beta = sqrtf(tmpgain) / tmpq;
                 tmp = (tmpgain + 1.0f) - (tmpgain - 1.0f) * cs + beta * sn;
 
-                c[0]=tmpgain * ((tmpgain + 1.0f) + (tmpgain - 1.0f) * cs + beta * sn) / tmp;
+                c[0] = tmpgain * ((tmpgain + 1.0f) + (tmpgain - 1.0f) * cs + beta * sn) / tmp;
                 c[1] = -2.0f * tmpgain * ((tmpgain - 1.0f) + (tmpgain + 1.0f) * cs) / tmp;
                 c[2] = tmpgain * ((tmpgain + 1.0f) + (tmpgain - 1.0f) * cs - beta * sn) / tmp;
                 d[1] = 2.0f * ((tmpgain - 1.0f) - (tmpgain + 1.0f) * cs) / tmp * -1.0f;
@@ -292,10 +284,7 @@ void AnalogFilter::computefiltercoefs(void)
             else
             {
                 c[0] = 1.0f;
-                c[1] = 0.0f;
-                c[2] = 0.0f;
-                d[1] = 0.0f;
-                d[2] = 0.0f;
+                c[1] = c[2] = d[1] = d[2] = 0.0f;
             }
             order = 2;
             break;
@@ -316,12 +305,13 @@ void AnalogFilter::setfreq(float frequency)
         rap = 1.0f / rap;
 
     oldabovenq = abovenq;
-    abovenq = frequency > (synth->halfsamplerate_f - 500.0);
+    abovenq = frequency > (synth->halfsamplerate_f - 500.0f);
 
     int nyquistthresh = (abovenq ^ oldabovenq);
 
     if (rap > 3.0f || nyquistthresh != 0)
-    {   // if the frequency is changed fast, it needs interpolation (now, filter and coeficients backup)
+    {   // if the frequency is changed fast, it needs interpolation
+        // (now, filter and coeficients backup)
         for (int i = 0; i < 3; ++i)
         {
             oldc[i] = c[i];
@@ -340,30 +330,35 @@ void AnalogFilter::setfreq(float frequency)
     firsttime = 0;
 }
 
+
 void AnalogFilter::setfreq_and_q(float frequency, float q_)
 {
     q = q_;
     setfreq(frequency);
 }
 
+
 void AnalogFilter::setq(float q_)
 {
     q = q_;
     computefiltercoefs();
 }
 
+
 void AnalogFilter::settype(int type_)
 {
     type = type_;
     computefiltercoefs();
 }
 
+
 void AnalogFilter::setgain(float dBgain)
 {
     gain = dB2rap(dBgain);
     computefiltercoefs();
 }
 
+
 void AnalogFilter::setstages(int stages_)
 {
     if (stages_ >= MAX_FILTER_STAGES)
@@ -373,9 +368,9 @@ void AnalogFilter::setstages(int stages_)
     computefiltercoefs();
 }
 
+
 void AnalogFilter::singlefilterout(float *smp, fstage &x, fstage &y, float *c, float *d)
 {
-    //unsigned int u;
     float y0;
     if (order == 1)
     {   // First order filter
@@ -384,11 +379,10 @@ void AnalogFilter::singlefilterout(float *smp, fstage &x, fstage &y, float *c, f
             y0 = smp[i] * c[0] + x.c1 * c[1] + y.c1 * d[1];
             y.c1 = y0;
             x.c1 = smp[i];
-            // output
-            smp[i] = y0;
+            smp[i] = y0; // out it goes
         }
     }
-    if (order==2) {// Second order filter
+    if (order == 2) { // Second order filter
         for (int i = 0; i < synth->buffersize; ++i)
         {
             y0 = smp[i] * c[0] + x.c1 * c[1] + x.c2 * c[2] + y.c1 * d[1] + y.c2 * d[2];
@@ -396,22 +390,19 @@ void AnalogFilter::singlefilterout(float *smp, fstage &x, fstage &y, float *c, f
             y.c1 = y0;
             x.c2 = x.c1;
             x.c1 = smp[i];
-            //output
-            smp[i] = y0;
+            smp[i] = y0; // out it goes
         }
     }
 }
+
+
 void AnalogFilter::filterout(float *smp)
 {
-    float *ismp = NULL;      // used if it needs interpolation
     if (needsinterpolation != 0)
     {
-        ismp = new float[synth->buffersize];
-        //for (int i = 0; i < synth->buffersize; ++i)
-        //    ismp[i] = smp[i];
-        memcpy(ismp, smp, synth->bufferbytes);
+        memcpy(tmpismp, smp, synth->bufferbytes);
         for (int i = 0; i < stages + 1; ++i)
-            singlefilterout(ismp, oldx[i], oldy[i], oldc, oldd);
+            singlefilterout(tmpismp, oldx[i], oldy[i], oldc, oldd);
     }
 
     for (int i = 0; i < stages + 1; ++i)
@@ -422,9 +413,8 @@ void AnalogFilter::filterout(float *smp)
         for (int i = 0; i < synth->buffersize; ++i)
         {
             float x = (float)i / synth->buffersize_f;
-            smp[i] = ismp[i] * (1.0f - x) + smp[i] * x;
+            smp[i] = tmpismp[i] * (1.0f - x) + smp[i] * x;
         }
-        delete [] ismp;
         needsinterpolation = 0;
     }
 
@@ -432,6 +422,7 @@ void AnalogFilter::filterout(float *smp)
         smp[i] *= outgain;
 }
 
+
 float AnalogFilter::H(float freq)
 {
     float fr = freq / synth->samplerate_f * PI * 2.0f;
