@@ -3,11 +3,12 @@
 
     Original ZynAddSubFX author Nasca Octavian Paul
     Copyright (C) 2002-2009 Nasca Octavian Paul
-    Copyright 2009-2010, Alan Calvert
+    Copyright 2009-2011, Alan Calvert
 
     This file is part of yoshimi, which is free software: you can redistribute
-    it and/or modify it under the terms of version 2 of the GNU General Public
-    License as published by the Free Software Foundation.
+    it and/or modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either version 2 of
+    the License, or (at your option) any later version.
 
     yoshimi is distributed in the hope that it will be useful, but WITHOUT ANY
     WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
@@ -18,7 +19,7 @@
     yoshimi; if not, write to the Free Software Foundation, Inc., 51 Franklin
     Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
-    This file is a derivative of a ZynAddSubFX original, modified October 2010
+    This file is derivative of ZynAddSubFX original code, modified April 2011
 */
 
 #include "Misc/SynthEngine.h"
@@ -33,9 +34,8 @@ Chorus::Chorus(bool insertion_, float *const efxoutl_, float *efxoutr_) :
     maxdelay = (int)(MAX_CHORUS_DELAY / 1000.0f * synth->samplerate_f);
     delayl = new float[maxdelay];
     delayr = new float[maxdelay];
-
     setpreset(Ppreset);
-
+    changepar(1, 64);
     lfo.effectlfoout(&lfol, &lfor);
     dl2 = getdelay(lfol);
     dr2 = getdelay(lfor);
@@ -119,8 +119,8 @@ void Chorus::out(float *smpsl, float *smpsr)
 
     for (int i = 0; i < synth->buffersize; ++i)
     {
-        efxoutl[i] *= (1.0f - panning);
-        efxoutr[i] *= panning;
+        efxoutl[i] *= pangainL;
+        efxoutr[i] *= pangainR;
     }
 }
 
@@ -162,20 +162,6 @@ void Chorus::setvolume(unsigned char Pvolume_)
 }
 
 
-void Chorus::setpanning(unsigned char Ppanning_)
-{
-    Ppanning = Ppanning_;
-    panning = Ppanning / 127.0f;
-}
-
-
-void Chorus::setlrcross(unsigned char Plrcross_)
-{
-    Plrcross = Plrcross_;
-    lrcross = Plrcross / 127.0f;
-}
-
-
 void Chorus::setpreset(unsigned char npreset)
 {
     const int PRESET_SIZE = 12;
