@@ -3,11 +3,12 @@
 
     Original ZynAddSubFX author Nasca Octavian Paul
     Copyright (C) 2002-2005 Nasca Octavian Paul
-    Copyright 2009-2010, Alan Calvert
+    Copyright 2009-2011, Alan Calvert
 
     This file is part of yoshimi, which is free software: you can redistribute
-    it and/or modify it under the terms of version 2 of the GNU General Public
-    License as published by the Free Software Foundation.
+    it and/or modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either version 2 of
+    the License, or (at your option) any later version.
 
     yoshimi is distributed in the hope that it will be useful, but WITHOUT ANY
     WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
@@ -18,7 +19,7 @@
     yoshimi; if not, write to the Free Software Foundation, Inc., 51 Franklin
     Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
-    This file is a derivative of a ZynAddSubFX original, modified October 2010
+    This file is derivative of ZynAddSubFX original code, modified April 2011
 */
 
 #ifndef DISTORSION_H
@@ -44,26 +45,20 @@ class Distorsion : public Effect, private MiscFuncs, WaveShapeSamples
     private:
         // Parametrii
         unsigned char Pvolume;       // Volumul or E/R
-        unsigned char Ppanning;      // Panning
-        unsigned char Plrcross;      // L/R Mixing
         unsigned char Pdrive;        // the input amplification
         unsigned char Plevel;        // the output amplification
         unsigned char Ptype;         // Distorsion type
         unsigned char Pnegate;       // if the input is negated
         unsigned char Plpf;          // lowpass filter
         unsigned char Phpf;          // highpass filter
-        unsigned char Pstereo;       // 0=mono,1=stereo
+        unsigned char Pstereo;       // 0 = mono, 1 = stereo
         unsigned char Pprefiltering; // if you want to do the filtering before the distorsion
 
         void setvolume(unsigned char Pvolume_);
-        void setpanning(unsigned char Ppanning_);
-        void setlrcross(unsigned char Plrcross_);
         void setlpf(unsigned char Plpf_);
         void sethpf(unsigned char Phpf_);
 
         // Real Parameters
-        float panning;
-        float lrcross;
         AnalogFilter *lpfl;
         AnalogFilter *lpfr;
         AnalogFilter *hpfl;
