@@ -3,11 +3,12 @@
 
     Original ZynAddSubFX author Nasca Octavian Paul
     Copyright (C) 2002-2005 Nasca Octavian Paul
-    Copyright 2009-2010, Alan Calvert
+    Copyright 2009-2011, Alan Calvert
 
     This file is part of yoshimi, which is free software: you can redistribute
-    it and/or modify it under the terms of version 2 of the GNU General Public
-    License as published by the Free Software Foundation.
+    it and/or modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either version 2 of
+    the License, or (at your option) any later version.
 
     yoshimi is distributed in the hope that it will be useful, but WITHOUT ANY
     WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
@@ -18,7 +19,7 @@
     yoshimi; if not, write to the Free Software Foundation, Inc., 51 Franklin
     Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
-    This file is a derivative of a ZynAddSubFX original, modified October 2010
+    This file is derivative of ZynAddSubFX original code, modified March 2011
 */
 
 #include "Misc/SynthEngine.h"
@@ -27,7 +28,6 @@
 DynamicFilter::DynamicFilter(bool insertion_, float *efxoutl_, float *efxoutr_) :
     Effect(insertion_, efxoutl_, efxoutr_, new FilterParams(0, 64, 64), 0),
     Pvolume(110),
-    Ppanning(64),
     Pdepth(0),
     Pampsns(90),
     Pampsnsinv(0),
@@ -36,6 +36,7 @@ DynamicFilter::DynamicFilter(bool insertion_, float *efxoutl_, float *efxoutr_)
     filterr(NULL)
 {
     setpreset(Ppreset);
+    changepar(1, 64); // pan
     cleanup();
 }
 
@@ -58,8 +59,8 @@ void DynamicFilter::out(float *smpsl, float *smpsr)
 
     float lfol, lfor;
     lfo.effectlfoout(&lfol, &lfor);
-    lfol *= depth * 5.0;
-    lfor *= depth * 5.0;
+    lfol *= depth * 5.0f;
+    lfor *= depth * 5.0f;
     float freq = filterpars->getfreq();
     float q = filterpars->getq();
 
@@ -89,8 +90,8 @@ void DynamicFilter::out(float *smpsl, float *smpsr)
     // panning
     for (int i = 0; i < synth->buffersize; ++i)
     {
-        efxoutl[i] *= (1.0 - panning);
-        efxoutr[i] *= panning;
+        efxoutl[i] *= pangainL;
+        efxoutr[i] *= pangainR;
     }
 }
 
@@ -120,12 +121,6 @@ void DynamicFilter::setvolume(unsigned char Pvolume_)
         volume = outvolume;
 }
 
-void DynamicFilter::setpanning(unsigned char Ppanning_)
-{
-    Ppanning = Ppanning_;
-    panning = Ppanning / 127.0f;
-}
-
 
 void DynamicFilter::setampsns(unsigned char Pampsns_)
 {
@@ -258,7 +253,8 @@ void DynamicFilter::setpreset(unsigned char npreset)
 //		printf("freq=%d  amp=%d  q=%d\n",filterpars->Pvowels[0].formants[i].freq,filterpars->Pvowels[0].formants[i].amp,filterpars->Pvowels[0].formants[i].q);
 //	    };
     if (insertion == 0)
-        changepar(0, presets[npreset][0] / 2); // lower the volume if this is system effect
+        changepar(0, presets[npreset][0] * 0.5f); // lower the volume if this is
+                                                  // system effect
     Ppreset = npreset;
     reinitfilter();
 }
