@@ -6,8 +6,9 @@
     Copyright 2009-2010, Alan Calvert
 
     This file is part of yoshimi, which is free software: you can redistribute
-    it and/or modify it under the terms of version 2 of the GNU General Public
-    License as published by the Free Software Foundation.
+    it and/or modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either version 2 of
+    the License, or (at your option) any later version.
 
     yoshimi is distributed in the hope that it will be useful, but WITHOUT ANY
     WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
@@ -18,7 +19,7 @@
     yoshimi; if not, write to the Free Software Foundation, Inc., 51 Franklin
     Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
-    This file is a derivative of a ZynAddSubFX original, modified October 2010
+    This file is derivative of ZynAddSubFX original code, modified October 2010
 */
 
 #include "Misc/SynthEngine.h"
@@ -63,8 +64,6 @@ void EQ::out(float *smpsl, float *smpsr)
     {
         efxoutl[i] *= volume;
         efxoutr[i] *= volume;
-        //efxoutl[i] = smpsl[i] * volume;
-        //efxoutr[i] = smpsr[i] * volume;
     }
     for (int i = 0; i < MAX_EQ_BANDS; ++i)
     {
@@ -91,10 +90,8 @@ void EQ::setpreset(unsigned char npreset)
     const int PRESET_SIZE = 1;
     const int NUM_PRESETS = 2;
     unsigned char presets[NUM_PRESETS][PRESET_SIZE] = {
-        // EQ 1
-        { 67 },
-        // EQ 2
-        { 67 }
+        { 67 }, // EQ 1
+        { 67 }  // EQ 2
     };
 
     if (npreset >= NUM_PRESETS)
