@@ -3,11 +3,12 @@
 
     Original ZynAddSubFX author Nasca Octavian Paul
     Copyright (C) 2002-2005 Nasca Octavian Paul
-    Copyright 2009-2010, Alan Calvert
+    Copyright 2009-2011, Alan Calvert
 
     This file is part of yoshimi, which is free software: you can redistribute
-    it and/or modify it under the terms of version 2 of the GNU General Public
-    License as published by the Free Software Foundation.
+    it and/or modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either version 2 of
+    the License, or (at your option) any later version.
 
     yoshimi is distributed in the hope that it will be useful, but WITHOUT ANY
     WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
@@ -18,7 +19,7 @@
     yoshimi; if not, write to the Free Software Foundation, Inc., 51 Franklin
     Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
-    This file is a derivative of a ZynAddSubFX original, modified October 2010
+    This file is derivative of ZynAddSubFX original code, modified March 2011
 */
 
 #include <cstdlib>
@@ -26,29 +27,31 @@
 #include "Misc/SynthEngine.h"
 #include "Effects/EffectLFO.h"
 
-EffectLFO::EffectLFO()
+EffectLFO::EffectLFO() :
+    Pfreq(40),
+    Prandomness(0),
+    PLFOtype(0),
+    Pstereo(64),
+    xl(0.0f),
+    xr(0.0f),
+    ampl1(synth->numRandom()),
+    ampl2(synth->numRandom()),
+    ampr1(synth->numRandom()),
+    ampr2(synth->numRandom()),
+    lfornd(0.0f)
 {
-    xl = xr = 0.0;
-    Pfreq = 40;
-    Prandomness = 0;
-    PLFOtype = 0;
-    Pstereo = 96;
-
     updateparams();
-
-    ampl1 = (1 - lfornd) + lfornd * synth->numRandom();
-    ampl2 = (1 - lfornd) + lfornd * synth->numRandom();
-    ampr1 = (1 - lfornd) + lfornd * synth->numRandom();
-    ampr2 = (1 - lfornd) + lfornd * synth->numRandom();
 }
 
+
 EffectLFO::~EffectLFO() { }
 
+
 // Update the changed parameters
 void EffectLFO::updateparams(void)
 {
     float lfofreq = (powf(2.0f, Pfreq / 127.0f * 10.0f) - 1.0f) * 0.03f;
-    incx = fabsf(lfofreq) * (float)synth->buffersize_f / synth->samplerate_f;
+    incx = fabsf(lfofreq) * synth->buffersize_f / synth->samplerate_f;
     if (incx > 0.49999999f)
         incx = 0.499999999f; // Limit the Frequency
 
@@ -58,10 +61,10 @@ void EffectLFO::updateparams(void)
     if (PLFOtype > 1)
         PLFOtype = 1; // this has to be updated if more lfo's are added
     lfotype = PLFOtype;
-
     xr = fmodf(xl + (Pstereo - 64.0f) / 127.0f + 1.0f, 1.0f);
 }
 
+
 // Compute the shape of the LFO
 float EffectLFO::getlfoshape(float x)
 {
@@ -84,6 +87,7 @@ float EffectLFO::getlfoshape(float x)
     return out;
 }
 
+
 // LFO output
 void EffectLFO::effectlfoout(float *outl, float *outr)
 {
