@@ -3,11 +3,12 @@
 
     Original ZynAddSubFX author Nasca Octavian Paul
     Copyright (C) 2002-2009 Nasca Octavian Paul
-    Copyright 2009-2010, Alan Calvert
+    Copyright 2009-2011, Alan Calvert
 
     This file is part of yoshimi, which is free software: you can redistribute
-    it and/or modify it under the terms of version 2 of the GNU General Public
-    License as published by the Free Software Foundation.
+    it and/or modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either version 2 of
+    the License, or (at your option) any later version.
 
     yoshimi is distributed in the hope that it will be useful, but WITHOUT ANY
     WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
@@ -18,9 +19,11 @@
     yoshimi; if not, write to the Free Software Foundation, Inc., 51 Franklin
     Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
-    This file is a derivative of a ZynAddSubFX original, modified October 2010
+    This file is derivative of ZynAddSubFX original code, modified April 2011
 */
 
+#include <fftw3.h>
+
 #include "Misc/SynthEngine.h"
 #include "Effects/EffectMgr.h"
 
@@ -32,8 +35,8 @@ EffectMgr::EffectMgr(const bool insertion_) :
     dryonly(false)
 {
     setpresettype("Peffect");
-    efxoutl = new float [synth->buffersize];
-    efxoutr = new float [synth->buffersize];
+    efxoutl = (float*)fftwf_malloc(synth->bufferbytes);
+    efxoutr = (float*)fftwf_malloc(synth->bufferbytes);
     memset(efxoutl, 0, synth->bufferbytes);
     memset(efxoutr, 0, synth->bufferbytes);
     defaults();
@@ -44,16 +47,18 @@ EffectMgr::~EffectMgr()
 {
     if (efx)
         delete efx;
-    delete [] efxoutl;
-    delete [] efxoutr;
+    fftwf_free(efxoutl);
+    fftwf_free(efxoutr);
 }
 
+
 void EffectMgr::defaults(void)
 {
     changeeffect(0);
     setdryonly(false);
 }
 
+
 // Change the effect
 void EffectMgr::changeeffect(int _nefx)
 {
@@ -100,12 +105,14 @@ void EffectMgr::changeeffect(int _nefx)
         filterpars = efx->filterpars;
 }
 
+
 // Obtain the effect number
 int EffectMgr::geteffect(void)
 {
     return (nefx);
 }
 
+
 // Cleanup the current effect
 void EffectMgr::cleanup(void)
 {
@@ -123,6 +130,7 @@ unsigned char EffectMgr::getpreset(void)
         return 0;
 }
 
+
 // Change the preset of the current effect
 void EffectMgr::changepreset_nolock(unsigned char npreset)
 {
@@ -130,6 +138,7 @@ void EffectMgr::changepreset_nolock(unsigned char npreset)
         efx->setpreset(npreset);
 }
 
+
 // Change the preset of the current effect(with thread locking)
 void EffectMgr::changepreset(unsigned char npreset)
 {
@@ -147,6 +156,7 @@ void EffectMgr::seteffectpar_nolock(int npar, unsigned char value)
     efx->changepar(npar, value);
 }
 
+
 // Change a parameter of the current effect (with thread locking)
 void EffectMgr::seteffectpar(int npar, unsigned char value)
 {
@@ -155,6 +165,7 @@ void EffectMgr::seteffectpar(int npar, unsigned char value)
     synth->actionLock(unlock);
 }
 
+
 // Get a parameter of the current effect
 unsigned char EffectMgr::geteffectpar(int npar)
 {
@@ -187,11 +198,13 @@ void EffectMgr::out(float *smpsl, float *smpsr)
     if (nefx == 7)
     {   // this is need only for the EQ effect
         // aca: another memcpy() candidate
-        for (int i = 0; i < synth->buffersize; ++i)
-        {
-            smpsl[i] = efxoutl[i];
-            smpsr[i] = efxoutr[i];
-        }
+        //for (int i = 0; i < synth->buffersize; ++i)
+        //{
+         //   smpsl[i] = efxoutl[i];
+         //   smpsr[i] = efxoutr[i];
+        //}
+        memcpy(smpsl, efxoutl, synth->bufferbytes);
+        memcpy(smpsr, efxoutr, synth->bufferbytes);
         return;
     }
 
@@ -238,6 +251,7 @@ void EffectMgr::out(float *smpsl, float *smpsr)
     }
 }
 
+
 // Get the effect volume for the system effect
 float EffectMgr::sysefxgetvolume(void)
 {
@@ -257,6 +271,7 @@ void EffectMgr::setdryonly(bool value)
     dryonly = value;
 }
 
+
 void EffectMgr::add2XML(XMLwrapper *xml)
 {
     xml->addpar("type", geteffect());
@@ -284,6 +299,7 @@ void EffectMgr::add2XML(XMLwrapper *xml)
     xml->endbranch();
 }
 
+
 void EffectMgr::getfromXML(XMLwrapper *xml)
 {
     changeeffect(xml->getpar127("type", geteffect()));
