@@ -68,7 +68,7 @@ Part::Part(Microtonal *microtonal_, FFTwrapper *fft_) :
         kit[n].padpars = NULL;
     }
 
-    kit[0].adpars = new ADnoteParameters(microtonal, fft);
+    kit[0].adpars = new ADnoteParameters(fft);
     kit[0].subpars = new SUBnoteParameters();
     kit[0].padpars = new PADnoteParameters(fft);
 
@@ -242,7 +242,7 @@ void Part::NoteOn(int note, int velocity, int masterkeyshift)
     int lastnotecopy = lastnote;  // Useful after lastnote has been changed.
 
     // MonoMem stuff:
-    if (!Ppolymode) // if Poly is off
+    if (!Ppolymode || ctl->legato.legato) // if Poly is off
     {
         monomemnotes.push_back(note);            // Add note to the list.
         monomem[note].velocity = velocity;       // Store this note's velocity.
@@ -268,9 +268,9 @@ void Part::NoteOn(int note, int velocity, int masterkeyshift)
             break;
         }
     }
-    if (Plegatomode && !Pdrummode)
+    if ((Plegatomode || ctl->legato.legato) && !Pdrummode)
     {
-        if (Ppolymode)
+        if (Ppolymode && Plegatomode)
         {
             Runtime.Log("Warning, poly and legato modes are both on.");
             Runtime.Log("That should not happen, so disabling legato mode");
@@ -366,7 +366,7 @@ void Part::NoteOn(int note, int velocity, int masterkeyshift)
         // still held down or sustained for the Portamento to activate
         // (that's like Legato).
         int portamento = 0;
-        if (Ppolymode || !ismonofirstnote)
+        if ((Ppolymode && !ctl->legato.legato) || !ismonofirstnote)
         {
             // I added a third argument to the
             // ctl->initportamento(...) function to be able
@@ -500,7 +500,8 @@ void Part::NoteOn(int note, int velocity, int masterkeyshift)
             partnote[pos].kititem[0].sendtoparteffect = 0;
             if (kit[0].Padenabled)
                 partnote[pos].kititem[0].adnote =
-                    new ADnote(kit[0].adpars, ctl, vel, portamento, note, false ); // not silent
+                    new ADnote(kit[0].adpars, ctl, notebasefreq, vel,
+                                portamento, note, false ); // not silent
             if (kit[0].Psubenabled)
                 partnote[pos].kititem[0].subnote =
                     new SUBnote(kit[0].subpars, ctl, notebasefreq, vel,
@@ -518,7 +519,8 @@ void Part::NoteOn(int note, int velocity, int masterkeyshift)
                 partnote[posb].kititem[0].sendtoparteffect = 0;
                 if (kit[0].Padenabled)
                     partnote[posb].kititem[0].adnote =
-                        new ADnote(kit[0].adpars, ctl, vel, portamento, note, true); // silent
+                        new ADnote(kit[0].adpars, ctl, notebasefreq, vel,
+                                    portamento, note, true); // silent
                 if (kit[0].Psubenabled)
                     partnote[posb].kititem[0].subnote =
                         new SUBnote(kit[0].subpars, ctl, notebasefreq, vel,
@@ -551,11 +553,12 @@ void Part::NoteOn(int note, int velocity, int masterkeyshift)
                 if (kit[item].adpars && kit[item].Padenabled)
                 {
                     partnote[pos].kititem[ci].adnote =
-                        new ADnote(kit[item].adpars, ctl, vel, portamento, note, false); // not silent
+                        new ADnote(kit[item].adpars, ctl, notebasefreq, vel,
+                                    portamento, note, false); // not silent
                 }
                 if (kit[item].subpars && kit[item].Psubenabled)
                     partnote[pos].kititem[ci].subnote =
-                        new SUBnote(kit[item].subpars, ctl,notebasefreq, vel,
+                        new SUBnote(kit[item].subpars, ctl, notebasefreq, vel,
                                     portamento, note, false);
 
                 if (kit[item].padpars && kit[item].Ppadenabled)
@@ -574,7 +577,8 @@ void Part::NoteOn(int note, int velocity, int masterkeyshift)
                     if (kit[item].adpars && kit[item].Padenabled)
                     {
                         partnote[posb].kititem[ci].adnote =
-                            new ADnote(kit[item].adpars, ctl, vel, portamento, note, true); // silent
+                            new ADnote(kit[item].adpars, ctl, notebasefreq, 
+                                        vel, portamento, note, true); // silent
                     }
                     if (kit[item].subpars && kit[item].Psubenabled)
                         partnote[posb].kititem[ci].subnote =
@@ -620,7 +624,7 @@ void Part::NoteOff(int note) //relase the key
         {
             if (!ctl->sustain.sustain)
             {   //the sustain pedal is not pushed
-                if (!Ppolymode && (not monomemnotes.empty()))
+                if ((!Ppolymode || ctl->legato.legato) && (not monomemnotes.empty()))
                     MonoMemRenote(); // To play most recent still held note.
                 else
                     RelaseNotePos(i);
@@ -679,6 +683,9 @@ void Part::SetController(unsigned int type, int par)
             if (!ctl->sustain.sustain)
                 RelaseSustainedKeys();
             break;
+        case C_legatofootswitch:
+            ctl->setlegato(par);
+            break;
         case C_allsoundsoff:
             AllNotesOff(); // Panic
             break;
@@ -725,7 +732,7 @@ void Part::SetController(unsigned int type, int par)
 void Part::RelaseSustainedKeys(void)
 {
     // Let's call MonoMemRenote() on some conditions:
-    if (Ppolymode == 0 && (not monomemnotes.empty()))
+    if ((Ppolymode == 0 || ctl->legato.legato) && (not monomemnotes.empty()))
         if (monomemnotes.back() != lastnote)
             // Sustain controller manipulation would cause repeated same note
             // respawn without this check.
@@ -828,7 +835,7 @@ void Part::setkeylimit(unsigned char Pkeylimit_)
         keylimit = POLIPHONY - 5;
 
     // release old keys if the number of notes>keylimit
-    if (Ppolymode)
+    if (Ppolymode && !ctl->legato.legato)
     {
         int notecount = 0;
         for (int i = 0; i < POLIPHONY; ++i)
@@ -1057,7 +1064,7 @@ void Part::setkititemstatus(int kititem, int Penabled_)
     else
     {
         if (!kit[kititem].adpars)
-            kit[kititem].adpars = new ADnoteParameters(microtonal, fft);
+            kit[kititem].adpars = new ADnoteParameters(fft);
         if (!kit[kititem].subpars)
             kit[kititem].subpars = new SUBnoteParameters();
         if (!kit[kititem].padpars)
