@@ -3,11 +3,12 @@
 
     Original ZynAddSubFX author Nasca Octavian Paul
     Copyright (C) 2002-2005 Nasca Octavian Paul
-    Copyright 2009-2010 Alan Calvert
+    Copyright 2009-2011 Alan Calvert
 
     This file is part of yoshimi, which is free software: you can redistribute
-    it and/or modify it under the terms of version 2 of the GNU General Public
-    License as published by the Free Software Foundation.
+    it and/or modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either version 2 of
+    the License, or (at your option) any later version.
 
     yoshimi is distributed in the hope that it will be useful, but WITHOUT ANY
     WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
@@ -18,7 +19,7 @@
     yoshimi; if not, write to the Free Software Foundation, Inc., 51 Franklin
     Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
-    This file is a derivative of a ZynAddSubFX original, modified November 2010
+    This file is derivative of original ZynAddSubFX code, modified March 2011
 */
 
 #ifndef PART_H
@@ -46,36 +47,36 @@ class FFTwrapper;
 class Part : private MiscFuncs, SynthHelper
 {
     public:
+        enum NoteStatus { KEY_OFF, KEY_PLAYING, KEY_RELASED_AND_SUSTAINED, KEY_RELASED };
+
         Part(Microtonal *microtonal_, FFTwrapper *fft_);
         ~Part();
+        inline float pannedVolLeft(void) { return volume * pangainL; }
+        inline float pannedVolRight(void) { return volume * pangainR; }
+        void defaults(void);
+        void defaultsinstrument(void);
+        void applyparameters(void);
+        void cleanup(void);
 
         // Midi commands implemented
-        void NoteOn(unsigned char note, unsigned char velocity, int masterkeyshift);
-        void NoteOff(unsigned char note);
+        void NoteOn(int note, int velocity, int masterkeyshift);
+        void NoteOff(int note);
         void AllNotesOff(void) { killallnotes = true; }; // panic, prepare all notes to be turned off
         void SetController(unsigned int type, int par);
         void RelaseSustainedKeys(void);
         void RelaseAllKeys(void);
-
         void ComputePartSmps(void);
 
-        // instrumentonly: 0 - save all, 1 - save only instrumnet,
-        //                 2 - save only instrument without the name(used in bank)
         bool saveXML(string filename); // true for load ok, otherwise false
         bool loadXMLinstrument(string filename);
-
         void add2XML(XMLwrapper *xml);
         void add2XMLinstrument(XMLwrapper *xml);
-
-        void defaults(void);
-        void defaultsinstrument(void);
-        void applyparameters(void);
         void getfromXML(XMLwrapper *xml);
         void getfromXMLinstrument(XMLwrapper *xml);
 
-        void cleanup(void);
+        Controller *ctl;
 
-        // the part's kit
+        // part's kit
         struct {
             string        Pname;
             unsigned char Penabled;
@@ -92,10 +93,9 @@ class Part : private MiscFuncs, SynthHelper
         } kit[NUM_KIT_ITEMS];
 
         // Part parameters
-        void setkeylimit(unsigned char Pkeylimit);
+        void setkeylimit(unsigned char Pkeylimit_);
         void setkititemstatus(int kititem, int Penabled_);
-        void setPvolume(char Pvolume);
-        void setPpanning(char Ppanning);
+        void setVolume(char value);
 
         unsigned char Penabled;
         unsigned char Pvolume;
@@ -103,7 +103,7 @@ class Part : private MiscFuncs, SynthHelper
         unsigned char Pmaxkey;
         unsigned char Pkeyshift;
         unsigned char Prcvchn;
-        unsigned char Ppanning;
+        char          Ppanning;
         unsigned char Pvelsns;     // velocity sensing (amplitude velocity scale)
         unsigned char Pveloffs;    // velocity offset
         unsigned char Pnoteon;     // if the part receives NoteOn messages
@@ -127,29 +127,30 @@ class Part : private MiscFuncs, SynthHelper
         float *partfxinputl[NUM_PART_EFX + 1]; // Left and right signal that pass thru part effects
         float *partfxinputr[NUM_PART_EFX + 1]; // [NUM_PART_EFX] is for "no effect" buffer
 
-        enum NoteStatus { KEY_OFF, KEY_PLAYING, KEY_RELASED_AND_SUSTAINED, KEY_RELASED };
-
-        float volume;      // applied by Master,
-        float oldvolumel;  //
-        float oldvolumer;  //
-        float panning;     //
-
-        Controller *ctl; // Part controllers
-
-        EffectMgr *partefx[NUM_PART_EFX];      // insertion part effects - part of the instrument
         unsigned char Pefxroute[NUM_PART_EFX]; // how the effect's output is
                                                // routed (to next effect/to out)
         bool Pefxbypass[NUM_PART_EFX + 1];     // if the effects are bypassed,
                                                // [NUM_PART_EFX] is for "no effect" buffer
+        EffectMgr *partefx[NUM_PART_EFX];      // insertion part effects - part of the instrument
 
+        float volume;      // applied by MasterAudio
+        float oldvolumel;
+        float oldvolumer;
+        float randompan;
         int lastnote;
 
+
     private:
         void KillNotePos(int pos);
         void RelaseNotePos(int pos);
         void MonoMemRenote(void); // MonoMem stuff.
+        void setPan(char panning);
+        void Mute(void) { __sync_or_and_fetch(&partMuted, 0xFF); }
+        void Unmute(void) { __sync_and_and_fetch(&partMuted, 0); }
+        bool isMuted(void) { return (__sync_add_and_fetch(&partMuted, 0) != 0); }
 
-        bool killallnotes;
+        Microtonal *microtonal;
+        FFTwrapper *fft;
 
         struct PartNotes {
             NoteStatus status;
@@ -164,11 +165,22 @@ class Part : private MiscFuncs, SynthHelper
             int time;
         };
 
-        int lastpos, lastposb;    // to keep track of previously used pos and posb.
-        bool lastlegatomodevalid; // to keep track of previous legatomodevalid.
+        PartNotes partnote[POLIPHONY];
+
+        int lastpos;              // previous pos and posb.
+        int lastposb;             // ^^
+        bool lastlegatomodevalid; // previous legatomodevalid.
+
+        float pangainL;
+        float pangainR;
+        float *tmpoutl;
+        float *tmpoutr;
+        float oldfreq; // for portamento
+        int partMuted;
+        bool killallnotes;
 
         // MonoMem stuff
-        list<unsigned char> monomemnotes; // a list to remember held notes.
+        list<unsigned char> monomemnotes; // held notes.
         struct {
             unsigned char velocity;
             int mkeyshift; // Not sure if masterkeyshift should be remembered.
@@ -178,14 +190,6 @@ class Part : private MiscFuncs, SynthHelper
                            // (the list only store note values). For example.
                            // 'monomem[note].velocity' would be the velocity
                            // value of the note 'note'.
-        PartNotes partnote[POLIPHONY];
-        float *tmpoutl;
-        float *tmpoutr;
-        float oldfreq; // for portamento
-        Microtonal *microtonal;
-        FFTwrapper *fft;
-        
-        int partMuted;
 };
 
 #endif
