@@ -33,15 +33,15 @@ class AlsaEngine : public MusicIO
     public:
         AlsaEngine();
         ~AlsaEngine() { };
-        
-        bool openAudio(WavRecord *recorder);
-        bool openMidi(WavRecord *recorder);
+
+        bool openAudio(void);
+        bool openMidi(void);
         bool Start(void);
         void Close(void);
-        
+
         unsigned int getSamplerate(void) { return audio.samplerate; };
         int getBuffersize(void) { return audio.period_size; };
-        
+
         string audioClientName(void);
         string midiClientName(void);
         int audioClientId(void) { return audio.alsaId; };
@@ -56,13 +56,11 @@ class AlsaEngine : public MusicIO
         bool alsaBad(int op_result, string err_msg);
         void closeAudio(void);
         void closeMidi(void);
-        
+
         void *AudioThread(void);
         static void *_AudioThread(void *arg);
         void *MidiThread(void);
         static void *_MidiThread(void *arg);
-        static void _audioCleanup(void *arg) { };
-        static void _midiCleanup(void *arg) { };
 
         snd_pcm_sframes_t (*pcmWrite)(snd_pcm_t *handle, const void *data,
                                       snd_pcm_uframes_t nframes);
