@@ -1,7 +1,7 @@
 /*
     AlsaJackClient.cpp - Jack audio / Alsa midi
-    
-    Copyright 2009-2010, Alan Calvert
+
+    Copyright 2009-2011, Alan Calvert
 
     This file is part of yoshimi, which is free software: you can
     redistribute it and/or modify it under the terms of the GNU General
@@ -20,9 +20,9 @@
 #include "Misc/Config.h"
 #include "MusicIO/AlsaJackClient.h"
 
-bool AlsaJackClient::openAudio(WavRecord *recorder)
+bool AlsaJackClient::openAudio(void)
 {
-    if (alsaEngine.openAudio(Recorder))
+    if (alsaEngine.openAudio())
     {
         Runtime.Samplerate = getSamplerate();
         Runtime.Buffersize = getBuffersize();
@@ -34,11 +34,11 @@ bool AlsaJackClient::openAudio(WavRecord *recorder)
 }
 
 
-bool AlsaJackClient::openMidi(WavRecord *recorder)
+bool AlsaJackClient::openMidi(void)
 {
     if (jackEngine.connectServer(Runtime.midiDevice))
     {
-        if (jackEngine.openMidi(Recorder))
+        if (jackEngine.openMidi())
         {
             return true;
         }
@@ -63,11 +63,3 @@ bool AlsaJackClient::Start(void)
         Runtime.Log("alsaEngine.Start() failed");
     return false;
 }
-
-
-void AlsaJackClient::Close(void)
-{
-    alsaEngine.Close();
-    jackEngine.Close();
-    MusicClient::Close();
-}
