@@ -50,6 +50,7 @@ class Controller
         void setfmamp(int value);
         void setvolume(int value);
         void setsustain(int value);
+        void setlegato(int value);
         void setportamento(int value);
         void setresonancecenter(int value);
         void setresonancebw(int value);
@@ -119,6 +120,11 @@ class Controller
             unsigned char receive;
         } sustain;
 
+        struct { // Legato
+            int data;
+            int legato;
+        } legato;
+
         struct { // Portamento
             // parameters
             int data;
