@@ -3,11 +3,12 @@
 
     Original ZynAddSubFX author Nasca Octavian Paul
     Copyright (C) 2002-2005 Nasca Octavian Paul
-    Copyright 2009-2010, Alan Calvert
+    Copyright 2009-2011, Alan Calvert
 
     This file is part of yoshimi, which is free software: you can redistribute
-    it and/or modify it under the terms of version 2 of the GNU General Public
-    License as published by the Free Software Foundation.
+    it and/or modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either version 2 of
+    the License, or (at your option) any later version.
 
     yoshimi is distributed in the hope that it will be useful, but WITHOUT ANY
     WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
@@ -18,7 +19,7 @@
     yoshimi; if not, write to the Free Software Foundation, Inc., 51 Franklin
     Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
-    This file is a derivative of a ZynAddSubFX original, modified October 2010
+    This file is derivative of ZynAddSubFX original code, modified January 2011
 */
 
 #ifndef ENVELOPE_PARAMS_H
@@ -39,7 +40,7 @@ class EnvelopeParams : public Presets
         void ADSRinit_filter(char A_val, char A_dt, char D_val, char D_dt,
                              char R_dt, char R_val);
         void ASRinit_bw(char A_val, char A_dt, char R_val, char R_dt);
-        void converttofree();
+        void converttofree(void);
 
         void add2XML(XMLwrapper *xml);
         void defaults(void);
@@ -67,7 +68,7 @@ class EnvelopeParams : public Presets
                      // 5 for ASR_bw parameters (bandwidth parameters)
 
     private:
-        void store2defaults();
+        void store2defaults(void);
 
         // Default parameters
         unsigned char Denvstretch;
