@@ -3,11 +3,12 @@
 
     Original ZynAddSubFX author Nasca Octavian Paul
     Copyright (C) 2002-2005 Nasca Octavian Paul
-    Copyright 2009, Alan Calvert
+    Copyright 2009-2011, Alan Calvert
 
     This file is part of yoshimi, which is free software: you can redistribute
-    it and/or modify it under the terms of version 2 of the GNU General Public
-    License as published by the Free Software Foundation.
+    it and/or modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either version 2 of
+    the License, or (at your option) any later version.
 
     yoshimi is distributed in the hope that it will be useful, but WITHOUT ANY
     WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
@@ -18,7 +19,7 @@
     yoshimi; if not, write to the Free Software Foundation, Inc., 51 Franklin
     Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
-    This file is a derivative of a ZynAddSubFX original, modified October 2009
+    This file is derivative of original ZynAddSubFX code, modified January 2011
 */
 
 #ifndef LFO_PARAMS_H
@@ -30,9 +31,10 @@
 class LFOParams : public Presets
 {
     public:
-        LFOParams(char Pfreq_, char Pintensity_, char Pstartphase_, char PLFOtype_,
-                  char Prandomness_, char Pdelay_, char Pcontinous, char fel_);
-        ~LFOParams() { };
+        LFOParams(float Pfreq_, unsigned char Pintensity_, unsigned char Pstartphase_,
+                  unsigned char PLFOtype_, unsigned char Prandomness_,
+                  unsigned char Pdelay_, unsigned char Pcontinous, int fel_);
+        ~LFOParams() { }
 
         void add2XML(XMLwrapper *xml);
         void defaults(void);
@@ -49,9 +51,8 @@ class LFOParams : public Presets
         unsigned char Pcontinous;
         unsigned char Pstretch;
 
-        int fel;         // what kind is the LFO
-                         // (0 - frequency, 1 - amplitude, 2 - filter)
-        static int time; // is used by Pcontinous parameter
+        int fel;         // kind of LFO - 0 frequency, 1 amplitude, 2 filter
+        static int time; // used by Pcontinous
 
     private:
         // Default parameters
