@@ -6,8 +6,9 @@
     Copyright 2009, Alan Calvert
 
     This file is part of yoshimi, which is free software: you can redistribute
-    it and/or modify it under the terms of version 2 of the GNU General Public
-    License as published by the Free Software Foundation.
+    it and/or modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either version 2 of
+    the License, or (at your option) any later version.
 
     yoshimi is distributed in the hope that it will be useful, but WITHOUT ANY
     WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
@@ -18,7 +19,7 @@
     yoshimi; if not, write to the Free Software Foundation, Inc., 51 Franklin
     Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
-    This file is a derivative of a ZynAddSubFX original, modified October 2009
+    This file is derivative of ZynAddSubFX original code, modified October 2009
 */
 
 #ifndef SUB_NOTE_PARAMETERS_H
@@ -34,15 +35,18 @@ class SUBnoteParameters : public Presets
     public:
         SUBnoteParameters();
         ~SUBnoteParameters();
-
+        void setPan(char pan);
+        bool randomPan(void) { return !PPanning; }
         void add2XML(XMLwrapper *xml);
         void defaults(void);
         void getfromXML(XMLwrapper *xml);
 
         // Amplitude Parametrers
-        bool Pstereo; // streo = true, mono = false
+        bool Pstereo; // true = stereo, false = mono
         unsigned char PVolume;
         unsigned char PPanning;
+        float pangainL;         // derived from PPanning
+        float pangainR;         // ^^
         unsigned char PAmpVelocityScaleFunction;
         EnvelopeParams *AmpEnvelope;
 
@@ -63,35 +67,29 @@ class SUBnoteParameters : public Presets
         EnvelopeParams *GlobalFilterEnvelope;
 
         // Other Parameters
+        unsigned char Pfixedfreq;   // If the base frequency is fixed to 440 Hz
 
-        // If the base frequency is fixed to 440 Hz
-        unsigned char Pfixedfreq;
+        unsigned char PfixedfreqET; // Equal temperate (this is used only if the
+                                    // Pfixedfreq is enabled)
+                                    // If this parameter is 0, the frequency is
+                                    // fixed (to 440 Hz)
+                                    // if this parameter is 64,
+                                    // 1 MIDI halftone -> 1 frequency halftone
 
-        /* Equal temperate (this is used only if the Pfixedfreq is enabled)
-           If this parameter is 0, the frequency is fixed (to 440 Hz);
-           if this parameter is 64, 1 MIDI halftone -> 1 frequency halftone */
-        unsigned char PfixedfreqET;
-
-        // how many times the filters are applied
-        unsigned char Pnumstages;
-
-        // bandwidth
+        unsigned char Pnumstages;   // how many times the filters are applied
         unsigned char Pbandwidth;
 
-        // How the magnitudes are computed (0=linear,1=-60dB,2=-60dB)
-        unsigned char Phmagtype;
+        unsigned char Phmagtype;    // how the magnitudes are computed
+                                    // 0 = linear, 1 = -60dB, 2 = -60dB
 
-        // Magnitudes
-        unsigned char Phmag[MAX_SUB_HARMONICS];
+        unsigned char Phmag[MAX_SUB_HARMONICS];   // Magnitudes
 
-        // Relative BandWidth ("64"=1.0)
-        unsigned char Phrelbw[MAX_SUB_HARMONICS];
+        unsigned char Phrelbw[MAX_SUB_HARMONICS]; // Relative BandWidth ("64"=1.0)
 
-        // how much the bandwidth is increased according to lower/higher frequency; 64-default
-        unsigned char Pbwscale;
+        unsigned char Pbwscale; // how much the bandwidth is increased according
+                                // to lower/higher frequency; 64-default
 
-        // how the harmonics start("0"=0,"1"=random,"2"=1)
-        unsigned char Pstart;
+        unsigned char Pstart;   // how the harmonics start, "0" = 0, "1" = random, "2" = 1
 };
 
 #endif
