@@ -3,11 +3,12 @@
 
     Original ZynAddSubFX author Nasca Octavian Paul
     Copyright (C) 2002-2005 Nasca Octavian Paul
-    Copyright 2009-2010 Alan Calvert
+    Copyright 2009-2011 Alan Calvert
 
     This file is part of yoshimi, which is free software: you can redistribute
-    it and/or modify it under the terms of version 2 of the GNU General Public
-    License as published by the Free Software Foundation.
+    it and/or modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either version 2 of
+    the License, or (at your option) any later version.
 
     yoshimi is distributed in the hope that it will be useful, but WITHOUT ANY
     WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
@@ -18,7 +19,7 @@
     yoshimi; if not, write to the Free Software Foundation, Inc., 51 Franklin
     Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
-    This file is a derivative of a ZynAddSubFX original, modified October 2010
+    This file is a derivative of a ZynAddSubFX original, modified January 2011
 */
 
 #include "Misc/SynthEngine.h"
@@ -52,42 +53,42 @@ Envelope::Envelope(EnvelopeParams *envpars, float basefreq)
 
     for (int i = 0; i < MAX_ENVELOPE_POINTS; ++i)
     {
-        float tmp = envpars->getdt(i) / 1000.0 * envstretch;
+        float tmp = envpars->getdt(i) / 1000.0f * envstretch;
         if (tmp > bufferdt)
             envdt[i] = bufferdt / tmp;
         else
-            envdt[i] = 2.0; // any value larger than 1
+            envdt[i] = 2.0f; // any value larger than 1
 
         switch (mode)
         {
             case 2:
-                envval[i] = (1.0 - envpars->Penvval[i] / 127.0) * MIN_ENVELOPE_DB;
+                envval[i] = (1.0f - envpars->Penvval[i] / 127.0f) * MIN_ENVELOPE_DB;
                 break;
             case 3:
-                envval[i] = (powf(2, 6.0 * fabsf(envpars->Penvval[i] - 64.0)
-                             / 64.0) - 1.0) * 100.0;
+                envval[i] =
+                    (powf(2.0f, 6.0f * fabsf(envpars->Penvval[i] - 64.0f) / 64.0f) - 1.0f) * 100.0f;
                 if (envpars->Penvval[i] < 64)
                     envval[i] = -envval[i];
                 break;
             case 4:
-                envval[i] = (envpars->Penvval[i] - 64.0) / 64.0 * 6.0; // 6 octaves (filtru)
+                envval[i] = (envpars->Penvval[i] - 64.0f) / 64.0f * 6.0f; // 6 octaves (filtru)
                 break;
             case 5:
-                envval[i] = (envpars->Penvval[i] - 64.0) / 64.0 * 10;
+                envval[i] = (envpars->Penvval[i] - 64.0f) / 64.0f * 10.0f;
                 break;
             default:
-                envval[i] = envpars->Penvval[i] / 127.0;
+                envval[i] = envpars->Penvval[i] / 127.0f;
         }
     }
 
-    envdt[0] = 1.0;
+    envdt[0] = 1.0f;
 
     currentpoint = 1; // the envelope starts from 1
     keyreleased = 0;
-    t = 0.0;
+    t = 0.0f;
     envfinish = 0;
     inct = envdt[1];
-    envoutval = 0.0;
+    envoutval = 0.0f;
 }
 
 
@@ -98,14 +99,13 @@ void Envelope::relasekey(void)
         return;
     keyreleased = 1;
     if (forcedrelase != 0)
-        t = 0.0;
+        t = 0.0f;
 }
 
 // Envelope Output
 float Envelope::envout(void)
 {
     float out;
-
     if (envfinish != 0)
     {   // if the envelope is finished
         envoutval = envval[envpoints - 1];
@@ -122,37 +122,37 @@ float Envelope::envout(void)
         int tmp = (envsustain < 0) ? (envpoints - 1) : (envsustain + 1);
         // if there is no sustain point, use the last point for release
 
-        if (envdt[tmp] <0.00000001)
+        if (envdt[tmp] <0.00000001f)
             out = envval[tmp];
         else
             out = envoutval + (envval[tmp] - envoutval) * t;
         t += envdt[tmp] * envstretch;
 
-        if (t >= 1.0)
+        if (t >= 1.0f)
         {
             currentpoint = envsustain + 2;
             forcedrelase = 0;
-            t = 0.0;
+            t = 0.0f;
             inct = envdt[currentpoint];
             if (currentpoint >= envpoints || envsustain < 0)
                 envfinish = 1;
         }
         return out;
     }
-    if (inct >= 1.0)
+    if (inct >= 1.0f)
         out = envval[currentpoint];
     else
         out = envval[currentpoint - 1] + (envval[currentpoint]
               - envval[currentpoint - 1]) * t;
 
     t += inct;
-    if (t >= 1.0)
+    if (t >= 1.0f)
     {
         if (currentpoint >= envpoints - 1)
             envfinish = 1;
         else
             currentpoint++;
-        t = 0.0;
+        t = 0.0f;
         inct = envdt[currentpoint];
     }
 
@@ -174,18 +174,18 @@ float Envelope::envout_dB(void)
         out = v1 + (v2 - v1) * t;
 
         t += inct;
-        if (t >= 1.0)
+        if (t >= 1.0f)
         {
-            t = 0.0;
+            t = 0.0f;
             inct = envdt[2];
             currentpoint++;
             out = v2;
         }
 
-        if (out > 0.001)
+        if (out > 0.001f)
             envoutval = rap2dB(out);
         else
-            envoutval = -40.0;
+            envoutval = -40.0f;
     } else
         out = dB2rap(envout());
 
