@@ -6,8 +6,9 @@
     Copyright 2009-2010 Alan Calvert
 
     This file is part of yoshimi, which is free software: you can redistribute
-    it and/or modify it under the terms of version 2 of the GNU General Public
-    License as published by the Free Software Foundation.
+    it and/or modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either version 2 of
+    the License, or (at your option) any later version.
 
     yoshimi is distributed in the hope that it will be useful, but WITHOUT ANY
     WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
@@ -115,12 +116,14 @@ class PADnote : public Carcass, private SynthHelper
         } NoteGlobalPar;
 
 
+        Controller *ctl;
         float globaloldamplitude;
         float globalnewamplitude;
         float velocity;
         float realfreq;
-        float *tmpwave;
-        Controller *ctl;
+//        float *tmpwave;
+        float randpanL;
+        float randpanR;
 
         // Legato vars
         struct {
